@@ -66,6 +66,7 @@ void print_help(char *argv[])
   printf("-wparopt options\n\t\toptions for parameter file:\n");
   printf("\t\t -H headername: header name for parameters. By default 'Default'\n");
   printf("-wafter\t\tWrite model after solve (useful if presolve used).\n");
+  printf("-wafters\tWrite scaled model after solve (useful to see scaling effect).\n");
   printf("-parse_only\tparse input file but do not solve\n");
   printf("-nonames\tIgnore variables and constraint names\n");
   printf("-norownames\tIgnore constraint names\n");
@@ -229,6 +230,7 @@ void print_help(char *argv[])
   printf("-Da <filename>\tDo a generic readable data dump of key lp_solve model variables\n\t\tafter solve.\n\t\tPrincipally for run difference and debugging purposes\n");
   printf("-i\t\tprint all intermediate valid solutions.\n\t\tCan give you useful solutions even if the total run time\n\t\tis too long\n");
   printf("-ia\t\tprint all intermediate (only non-zero values) valid solutions.\n\t\tCan give you useful solutions even if the total run time\n\t\tis too long\n");
+  printf("-ip\t\tprint solution with more precision\n");
   printf("-stat\t\tPrint model statistics\n");
   printf("-S <detail>\tPrint solution. If detail omitted, then -S2 is used.\n");
   printf("\t -S0: Print nothing\n");
@@ -239,6 +241,7 @@ void print_help(char *argv[])
   printf("\t -S5: Obj value+variables+constraints+duals+lp model\n");
   printf("\t -S6: Obj value+variables+constraints+duals+lp model+scales\n");
   printf("\t -S7: Obj value+variables+constraints+duals+lp model+scales+lp tableau\n");
+  printf("\t -Si: Also print solution if not feasible\n");
 }
 
 void print_cpu_times(const char *info)
@@ -540,8 +543,10 @@ int main(int argc, char *argv[])
   MYBOOL report = FALSE;
   MYBOOL nonames = FALSE, norownames = FALSE, nocolnames = FALSE;
   MYBOOL write_model_after = FALSE;
+  MYBOOL write_model_after_scaled = FALSE;
   MYBOOL noint = FALSE;
   int print_sol = -1;
+  MYBOOL print_solutions = FALSE;
   MYBOOL print_stats = FALSE;
   int floor_first = -1;
   MYBOOL do_set_bb_depthlimit = FALSE;
@@ -587,7 +592,7 @@ int main(int argc, char *argv[])
   REAL epsel = -1;
   MYBOOL do_set_break_at_value = FALSE;
   REAL break_at_value = 0;
-  REAL accuracy_error0, accuracy_error = -1;
+  REAL accuracy_error = -1;
   FILE *fpin = stdin;
   char *bfp = NULL;
   char *rxliname = NULL, *rxli = NULL, *rxlidata = NULL, *rxlioptions = NULL, *wxliname = NULL, *wxlisol = NULL, *wxli = NULL, *wxlioptions = NULL, *wxlisoloptions = NULL;
@@ -624,9 +629,27 @@ int main(int argc, char *argv[])
     else if(strcmp(argv[i], "-R") == 0)
       report = TRUE;
     else if(strcmp(argv[i], "-i") == 0)
-      print_sol = TRUE;
+    {
+      if (print_sol < 0)
+        print_sol = 0;
+      print_sol |= 1;
+    }
     else if(strcmp(argv[i], "-ia") == 0)
-      print_sol = AUTOMATIC;
+    {
+      if (print_sol < 0)
+        print_sol = 0;
+      print_sol |= AUTOMATIC;
+    }
+    else if(strcmp(argv[i], "-ip") == 0)
+    {
+      if (print_sol < 0)
+        print_sol = 0;
+      print_sol |= PRECISION;
+    }
+    else if(strcmp(argv[i], "-Si") == 0)
+    {
+        print_solutions = TRUE;
+    }
     else if(strcmp(argv[i], "-stat") == 0)
       print_stats = TRUE;
     else if(strcmp(argv[i], "-nonames") == 0)
@@ -847,6 +870,8 @@ int main(int argc, char *argv[])
       wfmps = argv[++i];
     else if(strcmp(argv[i],"-wafter") == 0)
       write_model_after = TRUE;
+    else if(strcmp(argv[i],"-wafters") == 0)
+      write_model_after_scaled = TRUE;
     else if(strcmp(argv[i],"-degen") == 0)
       set_value(&anti_degen1, ANTIDEGEN_DEFAULT);
     else if(strcmp(argv[i],"-degenf") == 0)
@@ -1095,14 +1120,14 @@ int main(int argc, char *argv[])
     }
   }
 
-  if(!write_model_after)
+  if(!write_model_after && !write_model_after_scaled)
     write_model(lp, plp, wlp, wmps, wfmps, wxli, NULL, wxliname, wxlioptions);
 
   if(print_stats)
     print_statistics(lp);
 
   if(parse_only) {
-    if(!write_model_after) {
+    if(!write_model_after && !write_model_after_scaled) {
       delete_lp(lp);
       EndOfPgr(0);
     }
@@ -1276,8 +1301,15 @@ int main(int argc, char *argv[])
     if(!write_basis(lp, wbasname))
       fprintf(stderr, "Unable to write basis file.\n");
 
-  if(write_model_after)
+  if(write_model_after || write_model_after_scaled)
+  {
+    MYBOOL scaling_used = lp->scaling_used;
+
+    if (write_model_after_scaled)
+      lp->scaling_used = FALSE;
     write_model(lp, plp, wlp, wmps, wfmps, wxli, NULL, wxliname, wxlioptions);
+    lp->scaling_used = scaling_used;
+  }
 
   write_model(lp, FALSE, NULL, NULL, NULL, NULL, wxlisol, wxliname, wxlisoloptions);
 
@@ -1313,28 +1345,7 @@ int main(int argc, char *argv[])
   case OPTIMAL:
   case PROCBREAK:
   case FEASFOUND:
-    if ((result == SUBOPTIMAL) && (PRINT_SOLUTION >= 1))
-      printf("Suboptimal solution\n");
-
-    if (result == PRESOLVED)
-      printf("Presolved solution\n");
-
-    if (PRINT_SOLUTION >= 1)
-      print_objective(lp);
-
-    if (PRINT_SOLUTION >= 2)
-      print_solution(lp, 1);
-
-    if (PRINT_SOLUTION >= 3)
-      print_constraints(lp, 1);
-
-    if (PRINT_SOLUTION >= 4)
-      print_duals(lp);
-
-    if(tracing)
-      fprintf(stderr,
-              "Branch & Bound depth: %d\nNodes processed: %.0f\nSimplex pivots: %.0f\nNumber of equal solutions: %d\n",
-              get_max_level(lp), (REAL) get_total_nodes(lp), (REAL) get_total_iter(lp), get_solutioncount(lp));
+    print_solutions = TRUE;
     break;
   case NOMEMORY:
     if (PRINT_SOLUTION >= 1)
@@ -1370,6 +1381,31 @@ int main(int argc, char *argv[])
     break;
   }
 
+  if (print_solutions) {
+    if ((result == SUBOPTIMAL) && (PRINT_SOLUTION >= 1))
+      printf("Suboptimal solution\n");
+
+    if (result == PRESOLVED)
+      printf("Presolved solution\n");
+
+    if (PRINT_SOLUTION >= 1)
+      print_objective(lp);
+
+    if (PRINT_SOLUTION >= 2)
+      print_solution(lp, 1);
+
+    if (PRINT_SOLUTION >= 3)
+      print_constraints(lp, 1);
+
+    if (PRINT_SOLUTION >= 4)
+      print_duals(lp);
+
+    if(tracing)
+      fprintf(stderr,
+              "Branch & Bound depth: %d\nNodes processed: %.0f\nSimplex pivots: %.0f\nNumber of equal solutions: %d\n",
+              get_max_level(lp), (REAL) get_total_nodes(lp), (REAL) get_total_iter(lp), get_solutioncount(lp));
+  }
+
   if (PRINT_SOLUTION >= 7)
     print_tableau(lp);
 
